FFit class

How a video should be inscribed into FView.

See also BoxFit

Constructors

FFit({Alignment alignment = Alignment.center, double aspectRatio = -1, double sizeFactor = 1.0})
const

Properties

alignment Alignment
Alignment for this FView Container. alignment is applied to Texture inner FView
final
aspectRatio double
aspectRatio controls inner video texture widget's aspect ratio.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeFactor double
The size of Texture is multiplied by this factor.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

ar4_3 → const FFit
As large as possible while still containing the video entirely within the target FView box. But change video's aspect ratio to 4:3.
ar16_9 → const FFit
As large as possible while still containing the video entirely within the target FView box. But change video's aspect ratio to 16:9.
contain → const FFit
As large as possible while still containing the video entirely within the target FView box.
cover → const FFit
As small as possible while still covering the entire target FView box.
fill → const FFit
Fill the target FView box by distorting the video's aspect ratio.
fitHeight → const FFit
Make sure the full height of the source is shown, regardless of whether this means the source overflows the target box horizontally.
fitWidth → const FFit
Make sure the full width of the source is shown, regardless of whether this means the source overflows the target box vertically.