aspectRatio property
aspectRatio controls inner video texture widget's aspect ratio.
A FView has an important child widget which display the video frame. This important inner widget is a Texture in this version. Normally, we want the aspectRatio of Texture to be same as playback's real video frame's aspectRatio. It's also the default behaviour of FView or if aspectRatio is assigned null or negative value.
If you want to change this default behaviour, just pass the aspectRatio you want.
Addition: double.infinate is a special value. The aspect ratio of inner Texture will be same as FView's aspect ratio if you set double.infinate to attribute aspectRatio.
Implementation
final double aspectRatio;