fitWidth constant

FFit const fitWidth

Make sure the full width of the source is shown, regardless of whether this means the source overflows the target box vertically.

Implementation

static const FFit fitWidth = FFit(sizeFactor: -1.5);