FLog class

API for sending log output

Generally, you should use the FLog.d(msg), FLog.i(msg), FLog.w(msg), and FLog.e(msg) methods to write logs. You can then view the logs in console/logcat.

The order in terms of verbosity, from least to most is ERROR, WARN, INFO, DEBUG, VERBOSE. Verbose should always be skipped in an application except during development. Debug logs are compiled in but stripped at runtime. Error, warning and info logs are always kept.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

d(String msg, {String tag = 'fplayer'}) → dynamic
log msg with FLogLevel.Debug level
e(String msg, {String tag = 'fplayer'}) → dynamic
log msg with FLogLevel.Error level
i(String msg, {String tag = 'fplayer'}) → dynamic
log msg with FLogLevel.Info level
log(FLogLevel level, String msg, String tag) → dynamic
log msg with level and tag to console
setLevel(FLogLevel level) → dynamic
Set global whole log level
v(String msg, {String tag = 'fplayer'}) → dynamic
log msg with FLogLevel.Verbose level
w(String msg, {String tag = 'fplayer'}) → dynamic
log msg with FLogLevel.Warn level