FLogLevel class

Annotations

Properties

hashCode int
The hash code for this object.
no setterinherited
level int
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

All → const FLogLevel
Priority constant for the FLog.log method;
Debug → const FLogLevel
Priority constant for the FLog.log method; use FLog.d(msg)
Detail → const FLogLevel
Priority constant for the FLog.log method;
Error → const FLogLevel
Priority constant for the FLog.log method; use FLog.e(msg)
Fatal → const FLogLevel
Info → const FLogLevel
Priority constant for the FLog.log method; use FLog.i(msg)
Silent → const FLogLevel
Verbose → const FLogLevel
Priority constant for the FLog.log method;
Warn → const FLogLevel
Priority constant for the FLog.log method; use FLog.w(msg)