FPlugin class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
initTexture(
) → Future< void> - Initialize texture for video rendering. Call this method before creating any FPlayer, typically in main() or after WidgetsFlutterBinding.ensureInitialized(). On Android 16+, this must be called after the Flutter engine is fully ready.
-
isDesktop(
) → bool -
isScreenKeptOn(
) → Future< bool> - Check if screen is kept on
-
keepScreenOn(
bool on) → Future< void> - Works on Android and iOS Keep screen on or not
-
releaseAudioFocus(
) → Future< void> - Only works on Android release audio focus
-
requestAudioFocus(
) → Future< void> - Only works on Android request audio focus for media usage
-
screenBrightness(
) → Future< double> -
Get the screen brightness.
The range of returned value is
0.0, 1.0 -
setOrientationAuto(
) → Future< void> -
setOrientationLandscape(
) → Future< bool> - Only works on Android and iOS return false if current orientation is landscape return true if current orientation is portrait and after this API call finished, the orientation becomes landscape. return false if can't change orientation.
-
setOrientationPortrait(
) → Future< bool> - Only works on Android and iOS
-
setScreenBrightness(
double value) → Future< void> -
Set screen brightness.
The range of
valueis0.0, 1.0