FView class

FView is a widget that can display the video frame of FPlayer.

Actually, it is a Container widget contains many children. The most important is a Texture which display the read video frame.

Inheritance

Constructors

FView({Key? key, required FPlayer player, double? width, double? height, FFit fit = FFit.contain, FFit fsFit = FFit.contain, FPanelWidgetBuilder panelBuilder = defaultFPanelBuilder, Color color = const Color(0xFF607D8B), ImageProvider<Object>? cover, bool fs = true, void onDispose(FData)?})
const

Properties

color Color
background color
final
cover ImageProvider<Object>?
cover image provider
final
fit FFit
How a video should be inscribed into this FView.
final
fs bool
Enable or disable the full screen
final
fsFit FFit
How a video should be inscribed into this FView at fullScreen mode.
final
hashCode int
The hash code for this object.
no setterinherited
height double?
Nullable, height of FView. If null, the height will be as big as possible.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDispose → void Function(FData)?
This method will be called when fView dispose. FData is managed inner FView. User can change fData in custom panel. See panelBuilder's second argument. And check if some value need to be recover on FView dispose.
final
panelBuilder FPanelWidgetBuilder
builder to build panel Widget
final
player FPlayer
The player that need display video by this FView. Will be passed to panelBuilder.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
Nullable, width of FView If null, the weight will be as big as possible.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited