fs property

bool fs
final

Enable or disable the full screen

If fs is true, FView make response to the FValue.fullScreen value changed, and push o new full screen mode page when FValue.fullScreen is true, pop full screen page when FValue.fullScreen become false.

If fs is false, FView never make response to the change of FValue.fullScreen. But you can still call FPlayer.enterFullScreen and FPlayer.exitFullScreen and make your own full screen pages.

Implementation

final bool fs;