FVolume class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
Static Properties
value
→ FVolumeEvent
get the system volume event.
a valid value is returned only if addListener is called and there's really volume changing
no setter
Static Methods
addListener (VoidCallback listener )
→ void
the listener wiil be nitified after system volume changed.
the value after change can be obtained through FVolume.value
down ({double step = _defaultStep })
→ Future <double >
decrease system volume by step, step must be in range 0.0, 1.0.
return the system volume value after decrease.
the return volume value may be not equals to the current volume - step.
getVol ()
→ Future <double >
get ths current system volume.
the range of returned value is 0.0, 1.0.
mute ()
→ Future <double >
Mute system volume.
return system volume after mute
removeListener (VoidCallback listener )
→ void
remove the listener set using addListener
setUIMode (int mode )
→ Future <void >
update the ui mode when system volume changing.
mode can be one of
{hideUIWhenPlayable , hideUIWhenPlaying , neverShowUI , alwaysShowUI }
setVol (double vol )
→ Future <double >
set system volume to vol.
the range of vol is 0.0, 1,0.
return the system volume value after set.
up ({double step = _defaultStep })
→ Future <double >
increase system volume by step, step must be in range 0.0, 1.0.
return the system volume value after increase.
the return volume value may be not equals to the current volume + step.