FVolumeCallback typedef

FVolumeCallback = void Function(FVolumeEvent value)

Volume changed callback func.

See FVolumeEvent value is the value of volume, and has been mapped into range 0.0, 1.0 true value of ui indicates that Android/iOS system volume changed UI is shown for this volume change event streamType shows track\stream type for this volume change, this value is always FVolume.STREAM_MUSIC in this version

Implementation

typedef FVolumeCallback = void Function(FVolumeEvent value);