FState enum
Values
- idle → const FState
-
The state when a FPlayer is just created. Native ijkplayer memory and objects also be alloced or created when a FPlayer is created.
- setDataSource() -> initialized
- reset() -> self
- release() -> end
- initialized → const FState
-
After call FPlayer.setDataSource on state idle, the state becomes initialized.
- prepareAsync() -> asyncPreparing
- reset() -> idle
- release() -> end
- asyncPreparing → const FState
-
There're many tasks to do during prepare, such as detect stream info in datasource, find and open decoder, start decode and refresh thread. So ijkplayer export a async api prepareAsync. When FPlayer.prepareAsync is called on state initialized, ths state changed to asyncPreparing immediately. After all task in prepare have finished, the state changed to prepared. Additionally, if any error occurs during prepare, the state will change to error.
- prepared → const FState
-
After finish all the heavy tasks during FPlayer.prepareAsync, the state becomes prepared from asyncPreparing.
- started → const FState
- paused → const FState
- completed → const FState
- stopped → const FState
-
- stop() -> self
- prepareAsync() -> asyncPreparing
- reset() -> idle
- release() -> end
- error → const FState
- end → const FState
-
- release() -> self
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited