MethodChannelFplayer class
An implementation of FplayerPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FplayerPlatform
- MethodChannelFplayer
Constructors
Properties
- eventChannel → EventChannel
-
The event channel used to receive events from the native platform.
final
- eventStream → Stream
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createPlayer(
) → Future< int?> -
override
-
getBrightness(
) → Future< double?> -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
isScreenKeptOn(
) → Future< bool?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onLoad(
) → Future< void> -
override
-
onUnload(
) → Future< void> -
override
-
releaseAudioFocus(
) → Future< void> -
override
-
releasePlayer(
int pid) → Future< void> -
override
-
requestAudioFocus(
) → Future< void> -
override
-
setBrightness(
double brightness) → Future< void> -
override
-
setLogLevel(
int level) → Future< void> -
override
-
setOrientationAuto(
) → Future< void> -
override
-
setOrientationLandscape(
) → Future< bool?> -
override
-
setOrientationPortrait(
) → Future< bool?> -
override
-
setScreenOn(
bool on) → Future< void> -
override
-
systemVolume(
) → Future< double?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
volUiMode(
int mode) → Future< void> -
override
-
volumeDown(
{double step = 1.0 / 16.0}) → Future< double?> -
override
-
volumeMute(
) → Future< double?> -
override
-
volumeSet(
double vol) → Future< double?> -
override
-
volumeUp(
{double step = 1.0 / 16.0}) → Future< double?> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited