FplayerPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- FplayerPlatform
- Implementers
Constructors
- FplayerPlatform()
- Constructs a FplayerPlatform.
Properties
- eventStream → Stream
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createPlayer(
) → Future< int?> -
getBrightness(
) → Future< double?> -
getPlatformVersion(
) → Future< String?> -
isScreenKeptOn(
) → Future< bool?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onLoad(
) → Future< void> -
onUnload(
) → Future< void> -
releaseAudioFocus(
) → Future< void> -
releasePlayer(
int pid) → Future< void> -
requestAudioFocus(
) → Future< void> -
setBrightness(
double brightness) → Future< void> -
setLogLevel(
int level) → Future< void> -
setOrientationAuto(
) → Future< void> -
setOrientationLandscape(
) → Future< bool?> -
setOrientationPortrait(
) → Future< bool?> -
setScreenOn(
bool on) → Future< void> -
systemVolume(
) → Future< double?> -
toString(
) → String -
A string representation of this object.
inherited
-
volUiMode(
int mode) → Future< void> -
volumeDown(
{double step = 1.0 / 16.0}) → Future< double?> -
volumeMute(
) → Future< double?> -
volumeSet(
double vol) → Future< double?> -
volumeUp(
{double step = 1.0 / 16.0}) → Future< double?>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FplayerPlatform
-
The default instance of FplayerPlatform to use.
getter/setter pair